@@ -1,10 +1,10 @@
+use app_arguments::{ApplicationArguments, Command};
 use quicli::prelude::*;
 use structopt::StructOpt;
-use app_arguments::{ApplicationArguments, Command};
 mod app_arguments;
 mod custom_config;
-mod common;
-mod mysql_struct;
+mod gen_struct;
+use gen_struct::GenStruct;
 
 extern crate inflector;
 
@@ -14,9 +14,14 @@ async fn main() -> CliResult {
     let key = args.command;
     match key {
         Command::Mysql(opt) => {
-            let s =read_file(&opt.file)?;
-            let config:custom_config::CustomConfig = serde_yaml::from_str(&s)?;
-            mysql_struct::gen_struct::run(config).await?;
+            let s = read_file(&opt.file)?;
+            let config: custom_config::CustomConfig = serde_yaml::from_str(&s)?;
+            let mysql = gen_struct::mysql_struct::MysqlStruct::new(
+                config,
+                opt.template_path,
+                opt.template_name,
+            )?;
+            mysql.run().await?;
         }
     }
     Ok(())
